==> aliyun-python-sdk-sas-2.0.2.tar.gz: aliyun-python-sdk-sas-2.0.2/aliyunsdksas/request/v20181203/GetCloudAssetCriteriaRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdksas.endpoint import endpoint_data

class GetCloudAssetCriteriaRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'GetCloudAssetCriteria')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_CloudAssetTypess(self): # RepeatList
		return self.get_query_params().get('CloudAssetTypes')

	def set_CloudAssetTypess(self, CloudAssetTypes):  # RepeatList
		for depth1 in range(len(CloudAssetTypes)):
			if CloudAssetTypes[depth1].get('AssetSubType') is not None:
				self.add_query_param('CloudAssetTypes.' + str(depth1 + 1) + '.AssetSubType', CloudAssetTypes[depth1].get('AssetSubType'))
			if CloudAssetTypes[depth1].get('AssetType') is not None:
				self.add_query_param('CloudAssetTypes.' + str(depth1 + 1) + '.AssetType', CloudAssetTypes[depth1].get('AssetType'))
	def get_Value(self): # String
		return self.get_query_params().get('Value')

	def set_Value(self, Value):  # String
		self.add_query_param('Value', Value)

==> aliyun-python-sdk-sas-2.0.3.tar.gz: aliyun-python-sdk-sas-2.0.3/aliyunsdksas/request/v20181203/GetCloudAssetCriteriaRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdksas.endpoint import endpoint_data

class GetCloudAssetCriteriaRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'GetCloudAssetCriteria','sas')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_CloudAssetTypess(self): # RepeatList
		return self.get_query_params().get('CloudAssetTypes')

	def set_CloudAssetTypess(self, CloudAssetTypes):  # RepeatList
		for depth1 in range(len(CloudAssetTypes)):
			if CloudAssetTypes[depth1].get('AssetSubType') is not None:
				self.add_query_param('CloudAssetTypes.' + str(depth1 + 1) + '.AssetSubType', CloudAssetTypes[depth1].get('AssetSubType'))
			if CloudAssetTypes[depth1].get('AssetType') is not None:
				self.add_query_param('CloudAssetTypes.' + str(depth1 + 1) + '.AssetType', CloudAssetTypes[depth1].get('AssetType'))
	def get_Value(self): # String
		return self.get_query_params().get('Value')

	def set_Value(self, Value):  # String
		self.add_query_param('Value', Value)
